/* Definitions file for GNU Emacs running on RISCiX 1.2 (bsd 4.3)
   Copyright (C) 1994, 2001, 2002, 2003, 2004, 2005,
                 2006, 2007, 2008  Free Software Foundation, Inc.

This file is part of GNU Emacs.

GNU Emacs is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

GNU Emacs is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Emacs; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.  */


#define  RISCiX_1_2	1
#define  RISCiX		12
#define  CRT0_O		/usr/lib/crt0.o
#include "bsd4-3.h"

/* arch-tag: f6b21e0a-f676-418a-9c8a-10fa8cd9dba7
   (do not change this comment) */
